Installation — WARIO 1.0.0 documentation

# Installation

Installing the WARIO editor from GitHub

## Installing the WARIO backend

The WARIO Editor requires the WARIO backend library to function. This can be installed from PyPi through the command

    pip install wario

This will also install any missing dependancies.

## Downloading the WARIO Editor

The latest version of the WARIO editor can be downloaded from the Github page. Once downloaded, unzip the folder and run `python WarioEditor.py`